@@ -62,7 +62,7 @@ class CDriveClient:
         if folder:
             child_objs = self.list(cdrive_path)['driveObjects']
             for cobj in child_objs:
-                local_path = os.path.join(os.path.join(kwargs['local_path'], cdrive_path[cdrive_path.rfind('/') + 1:]), cobj['name'])
+                local_path = os.path.join(kwargs['local_path'], cdrive_path[cdrive_path.rfind('/') + 1:])
                 self.download(cdrive_path + '/' + cobj['name'], local_path=local_path, folder=(cobj['type']=='Folder'))
         else:
             response = requests.get(self.api_url + 'download/?path=' + cdrive_path, headers={'Authorization':'Bearer ' + self.access_token})
